==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/ar/booking.php <==
<?php

return [
    'title' => 'الحجوزات',
    'singular_title' => 'حجز',
    'lbl_phone' => 'الهاتف:',
    'lbl_e-mail' => 'البريد الإلكتروني:',
    'lbl_with' => 'مع',
    'lbl_at' => 'في:',
    'lbl_note' => 'ملاحظة',
    'lbl_sub_tot' => 'المجموع الفرعي:',
    'lbl_got_to_payment' => 'الانتقال إلى الدفع',
    'lbl_complete_now' => 'إكمال الآن',
    'lbl_payment' => 'الدفع',
    'lbl_pay_now' => 'ادفع الآن',
    'lbl_is_paid' => 'مدفوع',
    'lbl_add_service' => 'إضافة خدمة',
    'lbl_add_package' => 'إضافة حزمة',
    'lbl_date' => 'التاريخ',
    'lbl_customer_name' => 'اسم العميل',
    'lbl_amount' => 'المبلغ',
    'lbl_duration' => 'المدة الزمنية',
    'lbl_staff_name' => 'اسم الموظف',
    'lbl_services' => 'الخدمات',
    'lbl_update_at' => 'تم التحديث في',
    'lbl_status' => 'الحالة',
    'booking_update' => 'تم تحديث الحجز',
    'booking_status_list' => 'قائمة حالات الحجز',
    'search_booking' => 'نتائج البحث عن الحجوزات.',
    'booking_detail' => 'تفاصيل الحجز',
    'booking_list' => 'قائمة الحجوزات',
    'status_update' => 'تم تحديث الحالة!',
    'booking_delete' => 'تم الحذف بنجاح',
    'booking_not_found' => 'الحجز غير موجود',
    'payment_done' => 'تم الدفع بنجاح',
    'booking_branch' => 'قائمة الفروع',
    'booking_timeslot' => 'قائمة فترات الحجز',
    'booking_category' => 'قائمة الفئات',
    'booking_sevice' => 'قائمة الخدمات',
    'booking_employee' => 'قائمة الموظفين',
    'booking_create' => 'تم إنشاء الحجز',
    'booking_action_invalid' => 'الإجراء غير صالح',
    'booking_service_update' => 'تم تحديث خدمة الحجز بنجاح',
    'payment_successfull' => 'تم الدفع بنجاح',
    'create_form' => 'تم إنشاء :form بنجاح',
    'lbl_action' => 'إجراء',
    'lbl_new_appointment' => 'موعد جديد',
    'lbl_appointment' => 'موعد',
    'lbl_advanced_filter' => 'مرشح متقدم',
    'lbl_booking_date' => 'تاريخ الحجز',
    'lbl_customer_name' => 'اسم العميل',
    'lbl_staff_name' => 'اسم الموظف',
    'lbl_services' => 'الخدمات',
    'lbl_payment_status' => 'حالة الدفع',
    'download_invoice' => 'تحميل الفاتورة',
    'name' => 'الاسم',
    'phone' => 'الهاتف',
    'email' => 'البريد الإلكتروني',
    'payment_method' => 'طريقة الدفع',
    'customer_info' => 'معلومات العميل',
    'services' => 'الخدمات',
    'unit_price' => 'سعر الوحدة',
    'qty' => 'الكمية',
    'total_price' => 'السعر الإجمالي',
    'tips' => 'النصائح',
    'tax' => 'الضريبة',
    'grand-total' => 'المجموع الكلي',
    'sub_total' => 'المجموع الفرعي',
    'products' => 'المنتجات',
    'invoice_data' => 'بيانات الفاتورة',
    'coupondiscount' => 'خصم القسيمة',
    'grand_total' => 'المجموع الكلي',
    'tips' => 'إكراميات',
    'billing_address' => 'عنوان الفاتورة'

];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/ar/booking.php <==
<?php

return [
    'title' => 'الحجوزات',
    'singular_title' => 'حجز',
    'lbl_phone' => 'الهاتف:',
    'lbl_e-mail' => 'البريد الإلكتروني:',
    'lbl_with' => 'مع',
    'lbl_at' => 'في:',
    'lbl_note' => 'ملاحظة',
    'lbl_sub_tot' => 'المجموع الفرعي:',
    'lbl_got_to_payment' => 'الانتقال إلى الدفع',
    'lbl_complete_now' => 'إكمال الآن',
    'lbl_payment' => 'الدفع',
    'lbl_pay_now' => 'ادفع الآن',
    'lbl_is_paid' => 'مدفوع',
    'lbl_add_service' => 'إضافة خدمة',
    'lbl_add_package' => 'إضافة حزمة',
    'lbl_date' => 'التاريخ',
    'lbl_customer_name' => 'عميل',
    'lbl_amount' => 'المبلغ',
    'lbl_duration' => 'المدة الزمنية',
    'lbl_staff_name' => 'الموظف',
    'lbl_services' => 'الخدمات',
    'lbl_update_at' => 'تم التحديث في',
    'lbl_status' => 'الحالة',
    'booking_update' => 'تم تحديث الحجز',
    'booking_status_list' => 'قائمة حالات الحجز',
    'search_booking' => 'نتائج البحث عن الحجوزات.',
    'booking_detail' => 'تفاصيل الحجز',
    'booking_list' => 'قائمة الحجوزات',
    'status_update' => 'تم تحديث الحالة!',
    'booking_delete' => 'تم الحذف بنجاح',
    'booking_not_found' => 'الحجز غير موجود',
    'payment_done' => 'تم الدفع بنجاح',
    'booking_branch' => 'قائمة الفروع',
    'booking_timeslot' => 'قائمة فترات الحجز',
    'booking_category' => 'قائمة الفئات',
    'booking_sevice' => 'قائمة الخدمات',
    'booking_employee' => 'قائمة الموظفين',
    'booking_create' => 'تم إنشاء الحجز',
    'booking_action_invalid' => 'الإجراء غير صالح',
    'booking_service_update' => 'تم تحديث خدمة الحجز بنجاح',
    'payment_successfull' => 'تم الدفع بنجاح',
    'create_form' => 'تم إنشاء :form بنجاح',
    'lbl_action' => 'إجراء',
    'lbl_new_appointment' => 'موعد جديد',
    'lbl_appointment' => 'موعد',
    'lbl_advanced_filter' => 'مرشح متقدم',
    'lbl_booking_date' => 'تاريخ الحجز',
    'lbl_customer_name' => 'اسم العميل',
    'lbl_staff_name' => 'اسم الموظف',
    'lbl_services' => 'الخدمات',
    'lbl_payment_status' => 'حالة الدفع',
    'download_invoice' => 'تحميل الفاتورة',
    'name' => 'الاسم',
    'phone' => 'الهاتف',
    'email' => 'البريد الإلكتروني',
    'payment_method' => 'طريقة الدفع',
    'customer_info' => 'معلومات العميل',
    'services' => 'الخدمات',
    'unit_price' => 'سعر الوحدة',
    'qty' => 'الكمية',
    'total_price' => 'السعر الإجمالي',
    'tips' => 'النصائح',
    'tax' => 'الضريبة',
    'grand-total' => 'المجموع الكلي',
    'sub_total' => 'المجموع الفرعي',
    'products' => 'المنتجات',
    'invoice_data' => 'بيانات الفاتورة',
    'coupondiscount' => 'خصم القسيمة',
    'grand_total' => 'المجموع الكلي',
    'tips' => 'إكراميات',
    'billing_address' => 'عنوان الفاتورة',
    'grand_total' => 'المجموع الكلي:',
    'lbl_packages' => 'الباقات',
    'lbl_add_more' => 'أضف المزيد',
    'lbl_packages_detail' => 'تفاصيل الباقات',
    'lbl_package_available' => 'الباقات المتاحة',
    'lbl_package_active' => 'لا يزال الباقة الخاصة بك نشطة',
    'lbl_view_all' => 'عرض الكل',
    'booking_date' => 'اختر تاريخ الحجز',
    'customer_name' => 'اختر اسم العميل',
    'staff_name' => 'اختر اسم الموظف',
    'select_service' => 'اختر الخدمات',
    'branch_name' => 'اسم الفرع',
    'invoice_time' => 'وقت الفاتورة',
    'payment_type' => 'نوع الدفع',
    'service_amount' => 'مبلغ الخدمة',
    'product_amount'=> 'مبلغ المنتج',
    'package_amount' => 'مبلغ الباقة',
    'tip_amount'=>'مبلغ الإكرامية',
    'total' => 'الإجمالي',
    'final_total'=>'الإجمالي النهائي',
    'booking_detail' => 'تفاصيل الحجز',
    'booked_on'=> 'تم الحجز في',
    'booked_by'=> 'تم الحجز بواسطة',
    'updated_on'=>'تم التحديث في',
    'updated_by'=>'تم التحديث بواسطة',
    'sale'=>'بيع #0',
    'with'=>'مع',
    'sold_by'=>'تم البيع بواسطة',
    'client_since'=>'عميل منذ ',
    'coupon_discount'=>'خصم الكوبون',



];
